pub enum Encoding {
Bit8,
Base64,
}Expand description
This parameter identifies the inline encoding used in a property value.
Variants
Bit8
The default encoding is “8BIT”, corresponding to a property value consisting of text.
Base64
The “BASE64” encoding type corresponds to a property value encoded using the “BASE64” encoding defined in [RFC2045].