pub struct TextWithLanguage<S: StringStorage> {
pub content: ValueText<S>,
pub language: Option<S>,
pub x_parameters: Vec<RawParameter<S>>,
pub retained_parameters: Vec<Parameter<S>>,
}Expand description
Text with language parameter only
This is a helper type used by text properties that support ONLY the LANGUAGE parameter (not ALTREP):
- 3.8.3.2:
TzName- Time zone name - 3.8.8.3:
RequestStatus- Request status
ALTREP and other standard parameters are preserved in retained_parameters
for round-trip compatibility.
Fields
content: ValueText<S>The actual text content
language: Option<S>Language code (optional)
x_parameters: Vec<RawParameter<S>>X-name parameters (custom experimental parameters)
retained_parameters: Vec<Parameter<S>>Unrecognized / Non-standard parameters (preserved for round-trip)
Implementations
Sourceimpl TextWithLanguage<Segments<'_>>
impl TextWithLanguage<Segments<'_>>
Sourcepub fn to_owned(&self) -> TextWithLanguage<String>
pub fn to_owned(&self) -> TextWithLanguage<String>
Convert borrowed TextWithLanguage to owned TextWithLanguage