Span

Struct Span 

pub struct Span {
    pub start: usize,
    pub end: usize,
}
A span representing a range in the source code

Fields

start: usize

Start position of the span

end: usize

End position of the span

Implementations

Source

impl Span

pub const fn new(start: usize, end: usize) -> Self

Create a new span from start and end positions

pub const fn into_range(self) -> Range<usize>

Convert to a standard range