TypedError

Enum TypedError 

#[non_exhaustive]
pub enum TypedError<'src> { ParameterDuplicated { parameter: ParameterKind<Segments<'src>>, span: Span, }, ParameterMultipleValuesDisallowed { parameter: ParameterKind<Segments<'src>>, span: Span, }, ParameterValueMustBeQuoted { parameter: ParameterKind<Segments<'src>>, value: Segments<'src>, span: Span, }, ParameterValueMustNotBeQuoted { parameter: ParameterKind<Segments<'src>>, value: Segments<'src>, span: Span, }, ParameterValueInvalid { parameter: ParameterKind<Segments<'src>>, value: Segments<'src>, span: Span, }, ValueTypeDisallowed { property: PropertyKind<Segments<'src>>, value_type: ValueType<Segments<'src>>, expected_types: &'static [ValueType<String>], span: Span, }, ValueSyntax { value: Segments<'src>, err: Rich<'src, char>, }, PropertyUnexpectedKind { expected: PropertyKind<Segments<'src>>, found: PropertyKind<Segments<'src>>, span: Span, }, PropertyMissingValue { property: PropertyKind<Segments<'src>>, span: Span, }, PropertyInvalidValueCount { property: PropertyKind<Segments<'src>>, expected: usize, found: usize, span: Span, }, PropertyInvalidValue { property: PropertyKind<Segments<'src>>, value: String, span: Span, }, PropertyUnexpectedValue { property: PropertyKind<Segments<'src>>, expected: &'static [ValueType<String>], found: ValueType<Segments<'src>>, span: Span, }, }
Errors that can occur during typed analysis of iCalendar components.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ParameterDuplicated

Parameter occurs multiple times when only one is allowed.

Fields

parameter: ParameterKind<Segments<'src>>

The parameter name

span: Span

The span of the error



ParameterMultipleValuesDisallowed

Parameter does not allow multiple values.

Fields

parameter: ParameterKind<Segments<'src>>

The parameter name

span: Span

The span of the error



ParameterValueMustBeQuoted

Parameter value must be quoted.

Fields

parameter: ParameterKind<Segments<'src>>

The parameter name

value: Segments<'src>

The parameter value

span: Span

The span of the error



ParameterValueMustNotBeQuoted

Parameter value must not be quoted.

Fields

parameter: ParameterKind<Segments<'src>>

The parameter name

value: Segments<'src>

The parameter value

span: Span

The span of the error



ParameterValueInvalid

Invalid parameter value.

Fields

parameter: ParameterKind<Segments<'src>>

The parameter name

value: Segments<'src>

The parameter value

span: Span

The span of the error



ValueTypeDisallowed

Value type is not allowed for this property.

Fields

property: PropertyKind<Segments<'src>>

The property name

value_type: ValueType<Segments<'src>>

The value type that was provided

expected_types: &'static [ValueType<String>]

The expected value types

span: Span

The span of the error



ValueSyntax

Syntax error in property value.

Fields

value: Segments<'src>

The value

err: Rich<'src, char>

The syntax error details



PropertyUnexpectedKind

Property kind does not match the expected type.

Fields

expected: PropertyKind<Segments<'src>>

Expected property kind

found: PropertyKind<Segments<'src>>

Actual property kind found

span: Span

The span of the error



PropertyMissingValue

Property has no values when at least one is required.

Fields

property: PropertyKind<Segments<'src>>

The property that is missing values

span: Span

The span of the error



PropertyInvalidValueCount

Property has an invalid value count.

Fields

property: PropertyKind<Segments<'src>>

The property kind

expected: usize

Expected number of values

found: usize

Actual number of values found

span: Span

The span of the error



PropertyInvalidValue

Property value is invalid or out of allowed range.

Fields

property: PropertyKind<Segments<'src>>

The property that has the invalid value

value: String

Description of why the value is invalid

span: Span

The span of the error



PropertyUnexpectedValue

Property value has unexpected type.

Fields

property: PropertyKind<Segments<'src>>

The property that has the wrong type

expected: &'static [ValueType<String>]

Expected value types

found: ValueType<Segments<'src>>

Actual value type found

span: Span

The span of the error

Implementations

Source

impl TypedError<'_>

pub fn span(&self) -> Span

Get the span of this error.