pub struct ValueText<S: StringStorage> { /* private fields */ }Expand description
Text value type defined in RFC 5545 Section 3.3.11.
Implementations
Sourceimpl<'a> ValueText<Segments<'a>>
impl<'a> ValueText<Segments<'a>>
Sourcepub fn resolve(&self) -> Cow<'a, str>
pub fn resolve(&self) -> Cow<'a, str>
Resolve the text value into a single string, processing escapes.
This version tries to avoid allocation when there’s only a single string token.
Sourcepub fn span(&self) -> Span
pub fn span(&self) -> Span
Get the full span from the first to the last token.
This method provides O(1) access to the span that covers all tokens
in the ValueText, from the first character to the last.
Sourcepub fn into_spanned_chars(self) -> ValueTextSpannedChars<'a> ⓘ
pub fn into_spanned_chars(self) -> ValueTextSpannedChars<'a> ⓘ
Create an iterator over characters with their spans.
This method provides a zero-copy iterator that yields each character along with its source position, enabling accurate error reporting.